@@ -15,9 +15,12 @@
 
 # Import APIs into API package:
 from eis.tenant.api.custom_schema_api import CustomSchemaApi
+from eis.tenant.api.dashboard_api import DashboardApi
+from eis.tenant.api.dashboard_group_api import DashboardGroupApi
 from eis.tenant.api.data_report_api import DataReportApi
 from eis.tenant.api.data_report_executor_api import DataReportExecutorApi
 from eis.tenant.api.delete_organization_invitations_api import DeleteOrganizationInvitationsApi
+from eis.tenant.api.health_check_api import HealthCheckApi
 from eis.tenant.api.invite_organizations_api import InviteOrganizationsApi
 from eis.tenant.api.invite_users_api import InviteUsersApi
 from eis.tenant.api.list_organization_invitations_api import ListOrganizationInvitationsApi
@@ -26,4 +29,3 @@ from eis.tenant.api.re_invite_an_organization_api import ReInviteAnOrganizationA
 from eis.tenant.api.roles_api import RolesApi
 from eis.tenant.api.settings_api import SettingsApi
 from eis.tenant.api.users_api import UsersApi
-from eis.tenant.api.default_api import DefaultApi
